<?php
$YOUTUBE = array(
	'j-rNb409GYg' => 'Phasendetektor & Verzögerungsausgleicher',
	'N4OjF2sJUHg' => 'Spektrumanalysator',
	'GsNfZ0TF-bk' => 'Klangerzeuger & Schlagzeug',
	'mkCHORwcZcU' => 'Triggersensor',
	'TfpJPsiouuU' => 'Parametrischer Entzerrer',
	'OQq5r1gr5tw' => 'Grafisher Entzerrer',
	'HXOjx3jfw2I' => 'Kompressor & Sidechain-Kompressor',
	'p6otNrilF0U' => 'Gate & Expander',
	'rvEhP_PRtzk' => 'Dynamikprozessor',
	'laExcuCMDY4' => 'Begrenzer',
	'BBcLpAx02UM' => 'Impulsantworten',
	'hEUauzc_j3U' => 'Slap-back Delay & Impulsnachhall',
	'D8evQrkY8nQ' => 'Oszillator',
	'JFXTcJb4DLs' => 'Latenzmessgerät',
	'RCdk94Hta3o' => 'Multi-band Kompressor',
	'kXCBRnJL_qo' => 'Profiler Mono',
	'J-ruYw9TwCE' => 'Room Builder',
	'TR_Ox7U_a84' => 'Multiband Expander',
	'7GOAM1O_RdY' => 'Multiband Gate',
	'CuySiF1VSj8' => 'Surge Filter & Loudness Compensator',
	'g8cShrKtmKo' => 'Crossover',
	'mEP1WyLFruY' => 'Artistic Delay',
	'MCIpQebU5o4' => 'Oscilloscope',
	'6ZuW28u1qns' => 'Multiband Dynamic Processor',
	'1Og6vAZ2BLo' => 'Noise Generator',
	'EFf4VqvMUXM' => 'A/B Tester & Mixer'
);

?>